"""add_missing_indexes_and_constraints

Revision ID: 7c26d62e8005
Revises: bc37e9c7ae19
Create Date: 2025-05-13 21:44:46.408395

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = '7c26d62e8005'
down_revision: Union[str, None] = 'bc37e9c7ae19'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    """Upgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_index('ix_expense_splits_user_id', 'expense_splits', ['user_id'], unique=False)
    op.create_index(op.f('ix_expenses_group_id'), 'expenses', ['group_id'], unique=False)
    op.create_index(op.f('ix_expenses_list_id'), 'expenses', ['list_id'], unique=False)
    op.create_index(op.f('ix_expenses_paid_by_user_id'), 'expenses', ['paid_by_user_id'], unique=False)
    op.create_index(op.f('ix_settlements_group_id'), 'settlements', ['group_id'], unique=False)
    op.create_index(op.f('ix_settlements_paid_by_user_id'), 'settlements', ['paid_by_user_id'], unique=False)
    op.create_index(op.f('ix_settlements_paid_to_user_id'), 'settlements', ['paid_to_user_id'], unique=False)

    # Add check constraints
    op.create_check_constraint(
        'chk_expense_context',
        'expenses',
        '(item_id IS NOT NULL) OR (list_id IS NOT NULL) OR (group_id IS NOT NULL)'
    )
    op.create_check_constraint(
        'chk_settlement_different_users',
        'settlements',
        'paid_by_user_id != paid_to_user_id'
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    """Downgrade schema."""
    # ### commands auto generated by Alembic - please adjust! ###
    # Drop check constraints
    op.drop_constraint('chk_settlement_different_users', 'settlements', type_='check')
    op.drop_constraint('chk_expense_context', 'expenses', type_='check')

    op.drop_index(op.f('ix_settlements_paid_to_user_id'), table_name='settlements')
    op.drop_index(op.f('ix_settlements_paid_by_user_id'), table_name='settlements')
    op.drop_index(op.f('ix_settlements_group_id'), table_name='settlements')
    op.drop_index(op.f('ix_expenses_paid_by_user_id'), table_name='expenses')
    op.drop_index(op.f('ix_expenses_list_id'), table_name='expenses')
    op.drop_index(op.f('ix_expenses_group_id'), table_name='expenses')
    op.drop_index('ix_expense_splits_user_id', table_name='expense_splits')
    # ### end Alembic commands ###
